aboutsummaryrefslogtreecommitdiff
path: root/build/zip-examples.js
diff options
context:
space:
mode:
Diffstat (limited to 'build/zip-examples.js')
-rw-r--r--build/zip-examples.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/build/zip-examples.js b/build/zip-examples.js
index e5eb56f22..b2f156502 100644
--- a/build/zip-examples.js
+++ b/build/zip-examples.js
@@ -44,8 +44,8 @@ if (!sh.test('-d', rootDocsDir)) {
// switch to the root dir
sh.cd(path.join(__dirname, '..'))
-// remove any previously created folder with the same name
-sh.rm('-rf', distFolder)
+// remove any previously created folder/zip with the same name
+sh.rm('-rf', [distFolder, `${distFolder}.zip`])
// create any folders so that `cp` works
sh.mkdir('-p', [